summaryrefslogtreecommitdiffstats
path: root/smb4k/configdlg/smb4kconfigdialog.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'smb4k/configdlg/smb4kconfigdialog.cpp')
-rw-r--r--smb4k/configdlg/smb4kconfigdialog.cpp70
1 files changed, 35 insertions, 35 deletions
diff --git a/smb4k/configdlg/smb4kconfigdialog.cpp b/smb4k/configdlg/smb4kconfigdialog.cpp
index 8ac95a4..4b62b2a 100644
--- a/smb4k/configdlg/smb4kconfigdialog.cpp
+++ b/smb4k/configdlg/smb4kconfigdialog.cpp
@@ -57,8 +57,8 @@
using namespace Smb4TDEGlobal;
-TDEInstance *Smb4KConfigDialogFactory::m_instance = 0L;
-TDEAboutData *Smb4KConfigDialogFactory::m_about = 0L;
+TDEInstance *Smb4TDEConfigDialogFactory::m_instance = 0L;
+TDEAboutData *Smb4TDEConfigDialogFactory::m_about = 0L;
// Variables we need to determine if super user entries
// have to be written to /etc/sudoers or /etc/super.tab
@@ -74,8 +74,8 @@ bool always_use_su = false;
bool close_dialog = false;
-Smb4KConfigDialog::Smb4KConfigDialog( Smb4KSettings *settings, TQWidget *parent, const char *name )
-: KConfigDialog( parent, name, settings )
+Smb4TDEConfigDialog::Smb4TDEConfigDialog( Smb4KSettings *settings, TQWidget *parent, const char *name )
+: TDEConfigDialog( parent, name, settings )
{
// FIXME: I guess, normally we would not need to close destructively,
// but at the moment there are issues with the KURLRequester in file
@@ -167,8 +167,8 @@ Smb4KConfigDialog::Smb4KConfigDialog( Smb4KSettings *settings, TQWidget *parent,
addPage( rsync_options, i18n( "Synchronization" ), "bottom" );
addPage( super_user_options, i18n( "Super User" ), "penguin" );
// Stuff that's not managed by KConfig XT is loaded by
// Smb4KConfigDialog::showEvent()!
// Resize the dialog
setInitialSize( configDialogSize( *(Smb4KSettings::self()->config()), "ConfigDialog" ) );
@@ -188,12 +188,12 @@ Smb4KConfigDialog::Smb4KConfigDialog( Smb4KSettings *settings, TQWidget *parent,
}
-Smb4KConfigDialog::~Smb4KConfigDialog()
+Smb4TDEConfigDialog::~Smb4TDEConfigDialog()
{
}
-void Smb4KConfigDialog::loadCustomSambaOptions()
+void Smb4TDEConfigDialog::loadCustomSambaOptions()
{
// Get the list view:
KListView *custom_list = static_cast<KListView *>( TQT_TQWIDGET(child( "CustomOptionsList", "KListView", true )) );
@@ -389,7 +389,7 @@ void Smb4KConfigDialog::loadCustomSambaOptions()
}
-void Smb4KConfigDialog::saveCustomSambaOptions()
+void Smb4TDEConfigDialog::saveCustomSambaOptions()
{
// Get the list view:
KListView *custom_list = static_cast<KListView *>( TQT_TQWIDGET(child( "CustomOptionsList", "KListView", true )) );
@@ -509,7 +509,7 @@ void Smb4KConfigDialog::saveCustomSambaOptions()
}
-void Smb4KConfigDialog::loadAuthenticationData()
+void Smb4TDEConfigDialog::loadAuthenticationData()
{
// Load the default login info and put it into the configuration
// page:
@@ -533,7 +533,7 @@ void Smb4KConfigDialog::loadAuthenticationData()
}
-void Smb4KConfigDialog::saveAuthenticationData()
+void Smb4TDEConfigDialog::saveAuthenticationData()
{
// Read the default login info from the configuration page
// and pass it to the password handler, but only if the wallet
@@ -566,7 +566,7 @@ void Smb4KConfigDialog::saveAuthenticationData()
}
-bool Smb4KConfigDialog::writeSuperUserEntries()
+bool Smb4TDEConfigDialog::writeSuperUserEntries()
{
TQRadioButton *sudo = static_cast<TQRadioButton *>( TQT_TQWIDGET(child( "SudoButton", TQRADIOBUTTON_OBJECT_NAME_STRING, true )) );
TQRadioButton *super = static_cast<TQRadioButton *>( TQT_TQWIDGET(child( "SuperButton", TQRADIOBUTTON_OBJECT_NAME_STRING, true )) );
@@ -638,7 +638,7 @@ bool Smb4KConfigDialog::writeSuperUserEntries()
}
-void Smb4KConfigDialog::removeSuperUserEntries()
+void Smb4TDEConfigDialog::removeSuperUserEntries()
{
TQRadioButton *sudo = static_cast<TQRadioButton *>( TQT_TQWIDGET(child( "SudoButton", TQRADIOBUTTON_OBJECT_NAME_STRING, true )) );
TQRadioButton *super = static_cast<TQRadioButton *>( TQT_TQWIDGET(child( "SuperButton", TQRADIOBUTTON_OBJECT_NAME_STRING, true )) );
@@ -686,7 +686,7 @@ void Smb4KConfigDialog::removeSuperUserEntries()
}
-bool Smb4KConfigDialog::checkSettings()
+bool Smb4TDEConfigDialog::checkSettings()
{
bool ok = true;
TQString issues = TQString();
@@ -917,7 +917,7 @@ bool Smb4KConfigDialog::checkSettings()
}
-void Smb4KConfigDialog::showEvent( TQShowEvent *e )
+void Smb4TDEConfigDialog::showEvent( TQShowEvent *e )
{
// Spontaneous show events come from outside the application.
// We do not want to react on them.
@@ -933,7 +933,7 @@ void Smb4KConfigDialog::showEvent( TQShowEvent *e )
// TQT_SLOT IMPLEMENTATIONS
/////////////////////////////////////////////////////////////////////////////
-void Smb4KConfigDialog::slotApply()
+void Smb4TDEConfigDialog::slotApply()
{
// If some settings are not complete, stop here and give
// the user the opportunity to fill in the needed string(s).
@@ -952,14 +952,14 @@ void Smb4KConfigDialog::slotApply()
setEnabled( false );
}
// The 'Apply' button will be disabled by KConfigDialog, so we do not
// need to do it here.
- KConfigDialog::slotApply();
+ TDEConfigDialog::slotApply();
}
-void Smb4KConfigDialog::slotOk()
+void Smb4TDEConfigDialog::slotOk()
{
// If some settings are not complete, stop here and give
// the user the opportunity to fill in the needed string(s).
@@ -978,7 +978,7 @@ void Smb4KConfigDialog::slotOk()
// Smb4KFileIO::finished() signal is received.
if ( !writeSuperUserEntries() )
{
- KConfigDialog::slotOk();
+ TDEConfigDialog::slotOk();
}
else
{
@@ -986,14 +986,14 @@ void Smb4KConfigDialog::slotOk()
// is received.
setEnabled( false );
- // Tell Smb4KConfigDialog::slotReceivedFileIOFinished()
+ // Tell Smb4TDEConfigDialog::slotReceivedFileIOFinished()
// to close the dialog.
close_dialog = true;
}
}
-void Smb4KConfigDialog::slotCancel()
+void Smb4TDEConfigDialog::slotCancel()
{
// Reset the custom Samba options tab:
Smb4KSambaOptions *samba_options = static_cast<Smb4KSambaOptions *>( TQT_TQWIDGET(child( "SambaOptions", "Smb4KSambaOptions", true )) );
@@ -1003,11 +1003,11 @@ void Smb4KConfigDialog::slotCancel()
samba_options->resetCustomTab();
}
- KConfigDialog::slotCancel();
+ TDEConfigDialog::slotCancel();
}
-void Smb4KConfigDialog::slotCustomSambaSettingsChanged()
+void Smb4TDEConfigDialog::slotCustomSambaSettingsChanged()
{
// Get the list view and all other input widgets:
KListView *view = static_cast<KListView *>( TQT_TQWIDGET(child( "CustomOptionsList", "KListView", true )) );
@@ -1123,7 +1123,7 @@ void Smb4KConfigDialog::slotCustomSambaSettingsChanged()
}
-void Smb4KConfigDialog::slotRemoveSuperUserEntries()
+void Smb4TDEConfigDialog::slotRemoveSuperUserEntries()
{
// Disable this widget until Smb4KFileIO::finished()
// is received.
@@ -1133,7 +1133,7 @@ void Smb4KConfigDialog::slotRemoveSuperUserEntries()
}
-void Smb4KConfigDialog::slotReceivedFileIOFailed()
+void Smb4TDEConfigDialog::slotReceivedFileIOFailed()
{
#ifdef __linux__
TQCheckBox *force = static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_UseForceUnmount", TQCHECKBOX_OBJECT_NAME_STRING, true )) );
@@ -1153,14 +1153,14 @@ void Smb4KConfigDialog::slotReceivedFileIOFailed()
}
-void Smb4KConfigDialog::slotReceivedFileIOFinished()
+void Smb4TDEConfigDialog::slotReceivedFileIOFinished()
{
// Enable the widget again.
setEnabled( true );
if ( close_dialog )
{
- KConfigDialog::slotOk();
+ TDEConfigDialog::slotOk();
}
}
@@ -1169,13 +1169,13 @@ void Smb4KConfigDialog::slotReceivedFileIOFinished()
// FACTORY STUFF
/////////////////////////////////////////////////////////////////////////////
-Smb4KConfigDialogFactory::Smb4KConfigDialogFactory()
+Smb4TDEConfigDialogFactory::Smb4TDEConfigDialogFactory()
: KLibFactory()
{
}
-Smb4KConfigDialogFactory::~Smb4KConfigDialogFactory()
+Smb4TDEConfigDialogFactory::~Smb4TDEConfigDialogFactory()
{
delete m_instance;
delete m_about;
@@ -1184,11 +1184,11 @@ Smb4KConfigDialogFactory::~Smb4KConfigDialogFactory()
}
-TDEInstance *Smb4KConfigDialogFactory::instance()
+TDEInstance *Smb4TDEConfigDialogFactory::instance()
{
if( !m_instance )
{
- m_about = new TDEAboutData( "smb4kconfigdialog", I18N_NOOP( "Smb4KConfigDialog" ), "1.0" );
+ m_about = new TDEAboutData( "smb4kconfigdialog", I18N_NOOP( "Smb4TDEConfigDialog" ), "1.0" );
m_about->addAuthor("Alexander Reinholdt", 0, "dustpuppy@users.berlios.de");
m_about->setLicense( TDEAboutData::License_GPL );
m_instance = new TDEInstance( m_about );
@@ -1198,10 +1198,10 @@ TDEInstance *Smb4KConfigDialogFactory::instance()
}
-TQObject *Smb4KConfigDialogFactory::createObject( TQObject *parent, const char *name, const char *,
+TQObject *Smb4TDEConfigDialogFactory::createObject( TQObject *parent, const char *name, const char *,
const TQStringList & )
{
- return TQT_TQOBJECT( new Smb4KConfigDialog( Smb4KSettings::self(), TQT_TQWIDGET( parent ), name ) );
+ return TQT_TQOBJECT( new Smb4TDEConfigDialog( Smb4KSettings::self(), TQT_TQWIDGET( parent ), name ) );
}
@@ -1215,7 +1215,7 @@ extern "C"
void *init_libsmb4kconfigdialog()
{
TDEGlobal::locale()->insertCatalogue( "smb4k" );
- return new Smb4KConfigDialogFactory;
+ return new Smb4TDEConfigDialogFactory;
}
}
@@ -167,8 +167,8 @@ Smb4KConfigDialog::Smb4KConfigDialog( Smb4KSettings *settings, TQWidget *parent,
addPage( rsync_options, i18n( "Synchronization" ), "bottom" );
addPage( super_user_options, i18n( "Super User" ), "penguin" );
- // Stuff that's not managed by KConfig XT is loaded by
- // Smb4KConfigDialog::showEvent()!
+ // Stuff that's not managed by TDEConfig XT is loaded by
+ // Smb4TDEConfigDialog::showEvent()!
// Resize the dialog
setInitialSize( configDialogSize( *(Smb4KSettings::self()->config()), "ConfigDialog" ) );
@@ -952,14 +952,14 @@ void Smb4KConfigDialog::slotApply()
setEnabled( false );
}
- // The 'Apply' button will be disabled by KConfigDialog, so we do not
+ // The 'Apply' button will be disabled by TDEConfigDialog, so we do not
// need to do it here.